bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 20. Aventiure
___________________________________________________ #### <Wie chvnk Ezel ze Bvrgonden nach Krimh' sande> [44b]
| ### az was in einen ziten do vro Helche erstarp ### vn– der kvnich Ezel vmbe ander vrovwen warp ### do rieten sine vrivnde in Burgonden lant ### zvo einer stolzen witwen div was vrov Kriemhilt genant
###### 1084 | ### Sit daz erstorben were der schonen Helchen lip ### si sprachen welt ir immer gewinnen edel wip ### di hosten vnd die besten die kvnich ie gewan ### so nemt die selben vrowen der starke Sifrit <was> ir man
###### 1085 | ### Do sprach der kvnich rike wie mohte daz ergan ### sid ich bin heiden vn– des tovffes niht han ### sist div vrovwe kristen des enlobet siz niht ### ez mvese sin ein wunder ob ez immer geschiht
###### 1086 | ### Do sprachen die snellen ob siz lihte tvot ### durch iwern namen hohen vnd iwer michel gvot ### so sol manz doch versuochen an daz vil edel wip ### ir mvget vil gerne minnen ir vil wetlichen lip
###### 1087 | ### Do sprach der kvnich edel wem ist iv bekant ### vnder iv bi Rine die lute vnd ovch daz lant ### do sprach der von Bechlarn der guote Ruodiger ### ich han erkant von kinde die vil edele kvnige her
###### 1088 | ### Gvnther vn– Gernot die edelen riter guot ### der dritte heizet Gyselher ir islicher tvot ### swaz er bester eren vnde tvgende mach began ### ovch habent ir alte mage noch daz selbe her getan
###### 1089 | ### Do sprach aber Ecel vrivnt dv sol mir sagen ### ob si in mime lande krone solde tragen ### vn– ist ir lip so schoene so mir ist geseit ### minen besten vrivnden sol ez nimmer werden leit
###### 1090 | ### Si gelichet sich mit schoene wol der vrovwen min ### Helchen der vil richen ia kvnde niht gesin ### in diser werlde schoener deheins kvniges wip ### den si lobet ze vrivnde der mach wol troesten sinen lip
###### 1091 | ### Er sprach so wirb ez Rvedeger also liep ich dir si ### vn– sol ich Kriemhilde geligen immer bi ### des wil ich dir lonen so ich beste kan ### vn– hast ovch minen willen so rehte verre getan
###### 1092 | ### Vz miner kamere so haiz ich dir geben ### daz dv vnd dine gesellen vrolichen mvgen leben ### von rossen vnd von kleideren allez daz dv wil ### des heize ich iv bereiten zvo der botschefte vil
###### 1093 | ### Des antwrte Ruedeger der markgraue rich ### gerte ich dines gvotes daz were vnlobelich ### ich wil din bote gerne wesen an den Rin ### mit min selbes gvote daz ich han von den henden din
###### 1094 | ### Do sprach der kvnich rich nv wenne welt ir varn ### nach der minneclichen got sol ivch bewarn ### der reise an allen eren vnd ovch die vrovwen min ### des helfe mir geluke daz si vns genedich muose sin
###### 1095 | ### Do sprach aber Ruedeger ê wir rvomen daz lant ### wir mvezen ê bereiten wafen vn– gewant [45a] ### also daz wirs ere vor fvrsten mugen han ### ich wil fuern zvo dem Rine funfhvndert wætlicher man
###### 1096 | ### Swa man mich ce Burgonde vnd die mine sehe ### daz ir islicher danne wolde <iehen> ### daz nie kvnich deheiner also manigen man ### so verre baz gesande danne dv ce Rine habest getan
###### 1097 | ### Vnd ob duz kvnich edel darvmbe niht wil lan ### si was dem besten manne Sifride vndertan ### dem Sigmvndes kinde den hastv hie gesehen ### man moht im grozer eren mit warheite iehen
###### 1098 | ### Do sprach kvnich Ezel was si des reken wip ### so was wol also tiwer des edelen fvrsten lip ### daz ich niht versmehen die kvnniginne sol ### durch ir vil groze schoene so gevellet si mir wol
###### 1099 | ### Do sprach der marchgraue so wil ich iv daz sagen ### daz wir vns heben hinnen in vier vnd zweinzech tagen ### ich enbivtez Goetelinde der lieben vrovwen min ### daz ich nach Kriemhilde selbe bote welle sin
###### 1100 | ### Hin ze Bechlarn do sande Ruedeger ### wart div markgrauinne trvrich vn– her ### er enbot ir daz er wolde dem kvnige werben wip ### si gedahte minnechliken an der schoenen Helchen lip
###### 1101 | ### Do div marchgrauinne die botschaft vernam ### ein teil was ez ir leide weinens si gezam ### obe si gewinnen solde vrovwen alsam ê ### so si dahte an Helken daz tet ir innerchlichen we
###### 1102 | ### Rvedeger von Vngern in siben tagen reit ### des was kvnich Ecel vro vn– ovch gemeit ### da ce der stat ce Wiene beræite man in die wat ### do mohte er siner reise niht langer haben rat
###### 1103 | ### Da ce Bechlarn wartete im Goetelint ### vn– div iunge marchgrauin Ruedegers kint ### sach ir vater gerne vnd die sine man ### do wart ein liebez bitten von schoenen vrovwen getan
###### 1104 | ### E der edel Ruedeger ze Bechlarn reit ### vz der stat ze Wiene do waren in div kleit ### rehte volleclichen vf den sovmen komen ### die fuoren in der maze daz in wart wenich iht genomen
###### 1105 | ### Do si ce Bechlaren komen in die stat ### die sinen reisegesellen herbergen bat ### der wirt vil minnechlichen vn– schuof in guot gemach ### Goetlint div riche den wirt si gerne komen sach
###### 1106 | ### Als tet sin liebiv <tohter> div iunge marchgrauin ### der kvnde nimmer sin komen lieber sin ### die helde vz Hunen lande wie gerne si si sach ### mit lachenden mvte div edel iunchvrovwe sprach
###### 1107 | ### Si vns groze willekomen min vater vn– sine man ### do wart ein schoene danken mit vlize da getan ### der iungen markgravin von edelen ritter gvot ### wol weste Goetlint des herren Ruodegers mvot [45b]
###### 1108 | ### Do si des nahtes bi Ruedegere lac ### wie guetliche vragen div marchgrauinne pflac ### war in gesendet hete der kvnich von Hûnen lant ### er sprach min vrov Goetlint ich tuonz iv gerne bekant
###### 1109 | ### Da sol ich mime herren werben ein ander wip ### sid div ist derstorben der schoenen Helken lip ### ich wil nach Kriemhilde riten an den Rin ### div sol hie zen Hvnen vrowe vil gewaltich sin
###### 1110 | ### Daz wolde got sprach Goetlint mohte daz geschehen ### sid wir ir so maniger eren hoeren iehen ### si ergazte vns miner vrovwen noch lihte in alten tagen ### wir mohten gerne si cen Hunen lazen krone tragen
###### 1111 | ### Do sprach der markgraue Ruediger truttinne min ### die mit mir svlen riten hinnen an den Rin ### den sult ir minneclichen bieten iwer guot ### so helde varent riche so sint si hohe gemvot
###### 1112 | ### Si sprach ez ist neheiner daz gerne von mir nimt ### ich engebe islichem daz im wol gezimt ### ê ir hinnen scheidet vn– ovch iwer man ### do sprach der marchgraue daz ist mir liebe getan
###### 1113 | ### Hei waz man richer pfelle von ir kammeren truoc ### der wart den edelen reken ce teile do genvoc ### ir sulet vlizeclichen von halse vnz vf die sporn ### die im darab gevielen die het im Ruodeger derkorn
###### 1114 | ### An dem sibenden morgen von Bechlaren reit ### der wirt min sinen reken wafen vnde kleit ### vorten si den vollen durch der Beire lant ### si wurden vf der straze durch rovben selten an gerant
###### 1115 | ### Inre tagen zvelfen si riten an den Rin ### do kvnden disiv mere niht verholen sin ### man seite ez dem kvnige vnd den sinen man ### da komen vremde geste der wirt do vragen began
###### 1116 | ### ob ieman bekande daz man im solde sagen ### man sach ir sovmere harte swere tragen ### daz si vil riche waren daz wart da wol bekant ### man schuof in herberge in der witen stat erhant
###### 1117 | ### Do die vil vnkvnden waren in bekomen ### do wart der selben herren vaste war genomen ### si wunderte wannen fueren die reken an den Rin ### der wirt Hagenen vragete wer die herren mohten sin
###### 1118 | ### Do sprach der helt von Trony ich han ir niht gesehen ### als wir si nv geschovwen ich han iv wol veriehen ### von swannen si riten her in dize lant ### si svln sin vil vremde ich habe si schiere bekant
###### 1119 | ### Den gesten herberge waren nv genomen ### in vil richiv kleider was der bote komen ### vnd sine hergesellen ze hove si do riten ### si fuorten guotiv kleider vil harte spehe gesniten
###### 1120 | ### Do sprach der snelle Hagene als ich mich kan verstan ### wand ich den herren lange niht gesehen han [46a] ### si varen wol gelike sam ez sei Ruedeger ### von hvnnissen landen der degen kuene vnde her
###### 1121 | ### Wie sol ich daz gelovben sprach der kvnich zehant ### daz der von Bekelar kome in dize lant ### als der kvnich Gvnther die rede vol sprach ### Hagne der kuene den gvoten Ruedegeren sach
###### 1122 | ### Er vnd sine vrivnde si liefen alle dan ### do sach man von den rossen funf hvndert riter stan ### do wurden wol enphangen die von Hunen lant ### boten nie getrvogen also herlich gewant
###### 1123 | ### Do sprach harte lûte von Trony Hagne ### nv sin gote willekomen dise degene ### der vogt von Bechellaren vn– alle sine man ### der antfanch wart mit eren den snellen Hunen getan
###### 1124 | ### Des kvniges nehesten mage die giengen da man sach ### Ortwin von Mece zvo Ruedegere sprach ### wir haben in aller wile mere nie gesehen ### geste so gerne des wil ich werliche iehen
###### 1125 | ### Des gruozes si do dancten den reken vber al ### mit den hergesinden si giengen in den sal ### da si den kvnich fvnden bi mangem kuenen man ### der herre stuont von sedele daz was durch groze zuht getan
###### 1126 | ### Wie rehte zuhtechlichen er zuo den boten gie ### Gvnther vn– Gernot vil flizechlich enpfie ### den gast mit sinen mannen als im wol gezam ### den guoten Ruodiger er bi der hende genam
###### 1127 | ### Er braht in zuo dem sedele da er selbe saz ### den gesten hiez er senchen vil gerne tet man daz ### mete den vil guoten vn– den besten win ### den man kvnde vinden in dem lande al vm den Rin
###### 1128 | ### Giselher vn– Gere die waren beide komen ### Dancwart vn– Volker die heten schiere vernomen ### vmbe dise geste si waren vro gemvot ### si enphiengen vor dem kvnnige die riter edele vn– guot
###### 1129 | ### Do sprach zuo sime herren von Trony Hagne ### ez solten immer dienen dise degne ### daz vns der markgraue zuo liebe hat <getan> ### des solte lon enphahen der schoenen Goeteline man
###### 1130 | ### Do sprach der kvnich Gunther ine kan daz niht verdagen ### wie si sich gehaben beide daz sult ir mir sagen ### Ezel vn– Helche vz der Hunen lant ### do sprach der marchgraue ich tuonz ich gerne bekant
###### 1131 | ### Do stuont er von dem sedele mit allen sinen man ### er sprach zuo dem kvnige vn– mac daz si getan ### daz ir mir furste erlovbet so wil ich niht verdagen ### die mere die ich bringe sol ich iv willechlichen sagen
###### 1132 | ### Er sprach swaz man iv mere bi iv enboten hat ### die erlovbe ich iv ze sagene ane frivnde rat ### ir svlt si lazen hoeren mich vnd mine man ### wan ich iv alle heren hie ze werbene gan [46b]
###### 1133 | ### Do sprach der bote biderbe iv enbivtet an den Rin ### getriwelichen dienest der groze voget min ### darzuo allen frivnden die ir mvget han ### ovch ist dise botschaft mit grozen triwen getan
###### 1134 | ### Iv bat der kvnich edele clagen sine not ### si volc ist ane vrevde min vrowe die ist tot ### Helche die vil rike mines herren wip ### an der ist nv verweiset vil maniger iunchfrovwen lip
###### 1135 | ### kint der edelen fursten die si gezogen hat ### da von ez inme lande vil iemerlichen stat ### dine hant nv leider niemannen der ir mit triwen phlege ### des wen ovch sich vil seine des kvniges sorge gelege
###### 1136 | ### Nv lon ime got sprach Gvnther daz er den dienst sin ### so willechlichen enbutet mir vn– den frivnden min ### den sinen gruoz ich gerne hie uernomen han ### daz sulen gerne dienen beide mage vn– mine man
###### 1137 | ### Do sprach von Burgvnde der reke Gernot ### die welt mach immer riwen der schoenen Helken tot ### durch ir vil manich tvgende der si kvnde pflegen ### der rede gestvont im Hagene der degen
###### 1138 | ### Do sprach aber Ruedeger der edel bote her ### sit ir mir kvnich erlovbet ich sol iv sagen mer ### waz iv min lieber herre her enboten hat ### sit im sin dinch nach Helchen so rehte kvmerlichen stat
###### 1139 | ### Man sagete minen herren Criemhilt si ane man ### her Sifrit si erstorben vn– ist daz so getan ### wolt ir ir des gunnen so sol si krone tragen ### vor Ecelen reken daz hiez ir min herre sagen
###### 1140 | ### Do sprach der kvnich riche wol gezogen was sin mvot ### si hoeret minen willen ob si ez gerne tuot ### den wil ich iv kvnden in disen drien tagen ### ê ich ez an ir fvnde zuowiv sol ich Ecelen versagen
###### 1141 | ### Die wile man den gesten hiez schaffen guot gemach ### in wart da so gedienet daz Rudiger des iach ### daz er da hete vrivnde vnter Gvnthers man ### Hagne im diente gerne er het im ê alsam getan
###### 1142 | ### Alsus beleip do Rudiger vnz an den driten tac ### der kvnich nach rate sande vil wislich er pflac ### vn– ob ez sine mage duhte guot getan ### daz Kriemhilt nemen solte den kvnich edelen zuo einem man
###### 1143 | ### Sie rieten ez algemeine niwan Hagne ### der sprach zuo Gvnther demn kuonen degne ### habt ir rehte sinne so wirt ez wol behuot ### vn– ob sis volgen wolte daz irz doch nimmer getuot
###### 1144 | ### Warumbe sprach do Gvnther solt ichs volgen niht ### swaz der kvnneginne liebes noch geschit ### daz sol ich ir wol gvnnen wan si ist die swester min ### wir soltenz selbe werben ob ez ir ere mohte sin
###### 1145 | ### Do sprach aber Hagne nv lat die rede stan ### het ir Ecelen kvnde als ich sin kvnde han [47a] ### sol si iv danne minnen als ich iv hoere <iehen> ### so ist iv alreste von schvlden ze sorgen geschehen
###### 1146 | ### Warvmbe sprach do Gvnther ich chan vil wol bewaren daz ### daz ich im kom so nahe daz ich deheinen haz ### von ime dulten muose vn– wurde si sin wip ### do sprach aber Hagne daz gerætet nimmer min lip
###### 1147 | ### Man hiez nach Gernote vn– Gyselhere gan ### ob die herren beide duhte guot getan ### daz Kriemhilt solde nemen den richen kvnich her ### noch widerreit ez Hagne vn– nieman mer
###### 1148 | ### Do sprach von Bvrgonden Gyselher der degen ### nv mvget ir frint Hagne noch der triwen pflegen ### ergezet si der leide vnd ir ir habet getan ### an swiv ir wol gelvnge daz svldet ir beliben lan
###### 1149 | ### Ia habet ir miner swester getan so mænigiv leit ### so sprach aber Giselher der reke vil gemeit ### daz si des hete schvlde daz si iv wære gram ### nie man noch einer vrovwen vrovde mere benam
###### 1150 | ### Daz ich daz wol bekenne daz tvon ich iv kvnt ### vnd sol si nemen Ecele vnd gelebet si an die stvnt ### si gett vns vil leide swie siz getreit an ### ia wirt ir da dienende vil manich wetlicher man
###### 1151 | ### Des antwurte do der kuene Gernot ### ez mach also beliben vnz an ir beider tot ### daz wir niht komen in Ecelen lant ### wir svln ir sin getriwe daz ist vns zen eren gewant
###### 1152 | ### Do sprach aber Hagne mir mac daz nieman gesagen ### sol div edel Kriemhilt Helken krone tragen ### si getvot vns leide swie si gefuege daz ### ir svlt ez lan beliben daz zimet iv reken mikel baz
###### 1153 | ### Mit zorne sprach do Giselher der schoene voten svn ### wir svln doch niht alle meinechlichen tuon ### swaz eren ir geschehe vro solten wir des sin ### swaz ir geredet Hagne ich diene ir durch die triwe min
###### 1154 | ### Do daz gehorte Hagne do wart er im gemvot ### Gernot vn– Giselher die stolzen riterre guot ### vn– Gvnther der riche ze iungist rieten daz ### ob ez lobete Kriemhilt si wolten ez lazen ane haz
###### 1155 | ### Do sprach der furste Gere ich wilz der vrovwen sagen ### daz si ir den kvnich Ecele laze wol behagen ### dem ist so manich reke mit vorhten vndertan ### er mach sich noch ergezen si leides ie gewan
###### 1156 | ### Do gie der snelle reke da er Kriemhilte <sach> ### si enpfie in guotliche wie balde er do sprach ### ir mvget mich gerne gruozen vn– geben petenbrot ### ivch wil geluche scheiden vz aller iwer not
###### 1157 | ### Ez hat durch iwer minne vrowe da her gesant ### ein der aller beste der ie kvnniges lant ### gewan mit vollen eren oder krone solde tragen ### ez werbent riter edele daz hiez iv iwer bruoder sagen [47b]
###### 1158 | ### Do sprach die iamers rike iv sol verbieten got ### vn– allen minen frivnden daz si deheinen spot ### an mir armer voben waz solt ich einen man ### der ie herzeliebe von guoten wibe gewan
###### 1159 | ### Si widerreit ez sere do komen aber sint ### Gernot ir bruoder vn– Giselher daz kint ### si baten minneclichen vn– trosten ir den mvot ### ob si den kvnich geneme daz wer ir werlichen guot
###### 1160 | ### Vberwinden kvnde nieman do daz edele wip ### daz si minnen wolte deheines mannes lip ### do baten si die degne nv lazet doch geschehen ### ob ir anders niht getuot daz ir den boten ruochet sehen
###### 1161 | ### Daz wil ich niht versprehen so sprach daz edele wip ### ich en sehe vil gerne den Ruedegers lip ### durch sine manige tvgende vn– wer er her niht gesant ### swerz ander boten were dem wer ich immer vnbekant
###### 1162 | ### Si sprach ir svlten morgen heizen her gan ### zuo miner kemenaten ich wil in hoeren lan ### vil gar den minen willen sol ich im selbe sagen ### ir war erniwet daz ir vil grozliche chlagen
###### 1163 | ### Do gert ovch niht anders der edele Ruediger ### wan daz er gesehe die kvnneginne her ### er weste sich so <wise> ob ez immer kunde ergan ### daz si sich den reken vberrede mvoze lan
###### 1164 | ### Des anderen morgens fruo do man die messe sanc ### die edelen boten komen do wart daz groz gedranc ### die mit Ruedigere zuo houe wolten gan ### der sach man da gekleidet vil manigen herlichen man
###### 1165 | ### Criemhilt div schoene vn– vil reine gemvot ### si warte Ruedigere dem edelen boten guot ### der vant si in der wete die si alle tage truoch ### da bi truoch ir gesinde richer cleider genvoch
###### 1166 | ### Si gie im engegene zuo der thuor stan ### vn– enpfiench vil guotliche den edelen man ### niwan selbe zwelfter er darin ze rat gie ### man bot im grozen dienst in komen hoher boten nie
###### 1167 | ### Man hiez den herren sizen vn– die sine man ### die zvene marchgrauen die sach man vor ir stan ### Ekewart vn– Gern die edelen riter guot ### durch die hvsfrowen si sahen nieman wol gemvot
###### 1168 | ### Si sahen vor ir sicen vil manige schoene meit ### do pflac niwan iamers die vrovwe vil gemeit ### ir wat was vor den brusten von heizen trehen naz ### der edele marchgraue wol sach an Kriemhilde daz
###### 1169 | ### Do sprach der bote here vil edel kvniges kint ### mir vn– minen gesellen die mit mir komen sint ### svlt ir daz erlovben daz wir vor iv stan ### vn– iv sagen div mere warnach her geriten han
###### 1170 | ### Nv si iv erlovbet sprach div kvnnegin ### swaz ir reden wellet also stat min sin [48a] ### daz ich gerne hoere ir sit ein bote guot ### die anderen do wol horten den ir vngwilligen mvot
###### 1171 | ### Do sprach von Bekelaren der furste Ruediger ### mit triwen groze liebe Ecel ein kvnnich her ### hat iv enboten vrovwe her in dize lant ### er hat nach iwer minne vil guote reken her gesant
###### 1172 | ### Er enbivtet iv minnecliche liep ane leit ### steter frivntschefte der si er iv bereit ### als ê tet vron Helchem div im ze herzen lac ### ia hat er nach ir tvgenden vil dike vnvrolichen tac
###### 1173 | ### Do sprach div kvnniginne marchgrave Rudiger ### wer ieman der bekande minen scharphen ser ### des bete nmich niht truoten noch deheinen man ### ia verlos ich einen den vrovwe ie gewan
###### 1174 | ### Waz mac ergecen leides sprach der vil kuene man ### wan frivntliche liebe swer die kan began ### vn– der dan ein kvset der im ze herce kvmt ### von hercenlichen leide niht so grozlichen frumt
###### 1175 | ### Vn– geruochet ir ze minnen den edelen herren min ### zwelf vil richer krone svlt ir gewaltich sin ### darzuo git iv min herre wol drizech fursten lant ### div elliv hat betwungen sin vil ellenthaftiv hant
###### 1176 | ### Ir svlt ovch werden vrovwe vber manigen werden man ### die miner vrovwen Helchen waren vndertan ### vn– vber manige vrovwe der si het gewalt ### von hoher fvrsten kvnne sprach der kuene degen balt
###### 1177 | ### Darzuo git iv min herre daz heizet er iv sagen ### ob ir geruochet chrone bi dem kvnige tragen ### gewalt den aller hohesten den Helche ie gewan ### den svlt ir gewaltechlichen haben vor Ecelen man
###### 1178 | ### Do sprach div kvniginne wie mohte minen lip ### immer des gelusten daz ich wurde heldes wip ### mir hat der tot an eime so rehte leide getan ### des ich vnz an min ende mvoz vnfrolichen stan
###### 1179 | ### Do sprachen aber die Hunen kvnniginne rich ### ivwer leben wirt bi Ezele so rehte lobelich ### daz ez ivch immer wune ist daz ez ergat ### wan der kvnich rike vil manigen cieren degen hat
###### 1180 | ### Helchen iuncvrowen vn– ivwre megetin ### solten di bi ein ander ein gesinde sin ### da bi moehten reken werden wol gemvot ### latez iv vrovwe raten ez wirt iv werlichen guot
###### 1181 | ### Si sprach in ir zvhten nu lat die rede stan ### vnz morgen vruo so sult ir her gan ### ich wil iv antwurten des ir da habet muot ### des muosen do volgen die recken kuene vn– guot
###### 1182 | ### Do si zen herbergen alle komen dan ### do hiez die edele vruewe nach Giselhere gan ### vn– ovch nach ir mvoter den besten sagt si daz ### daz si gezeme weinens vn– niht anders baz [48b]
###### 1183 | ### Do sprach ir bruoder Gyselher swester mir ist geseit ### vn– wilz ovch wol gelovben daz alliu diniv leit ### der kvnich Ecel wende vn– nimes dvn zeinem man ### swaz ander ieman rate so dvnchet ez mich guot getan
###### 1184 | ### Er mac dich wol ergecen sprach aber Gyselher ### von Roten zuo dem Rine von der Elbe unz an daz mere ### so ist kvnich deheiner so gewaltich niht ### dv mach dich vreuwen balde so er din ze konen giht
###### 1185 | ### Si sprach lieber bruoder zwiv ratestu mir daz ### clagen vn– weinen mir immer zeme baz ### wie sold ich vor reken da ze hove gan ### wart min lip ie schoene des bin ich ane getan
###### 1186 | ### Do sprach die vrovwe vote ir lieben tohter <zuo> ### swaz dine bruoder raten liebez kint daz tuo ### volge dinen vrivnden so mac dir wol geschehen ### ich han dich doch so lange mit grozem iamer <gesehen>
###### 1187 | ### Do bat si got vil dike fuegen ir den rat ### daz si ce gebene hete golt silber vn– wat ### sam ê bi ir manne do er noch was gesvnt ### si gelebte doch nimmer mere so vroliche stvnt
###### 1188 | ### Si gedahte in ir sinne vn– sol ich minen lip ### geben eime heide ich bin ein cristen wip ### des mvoz ich zer werlte inmer schanden han ### git er mir alle riche ez ist von mir vngetan
###### 1189 | ### Da mit siz lie beliben die naht vnz an den tac ### div vrovwe an ir bette mit vil gedanken lac ### div ir vil lieben ovgen getrvkenten nie ### vnz si aber den morgen hin ze mettin gie
###### 1190 | ### Ze rehter messezite die kvnige waren komen ### si heten aber ir swester vnder die hende genomen ### ia rietens ir ze minnen den kvnich von Hivnen lant ### die vrovwen ir deheine luzzel vrolicher vant
###### 1191 | ### Do hiez man daz gewinnen die Ecelen man ### die nv mit vrlovbe gerne weren dan ### geworben oder gescheiden swie ez do moehte sin ### ze hove komen do Rudiger die helde <rieten> wider in
###### 1192 | ### daz man rehte erfuore des edelen fursten mvot ### vn– teten daz bi cite daz divhtes alle guot ### ir wege weren verre wider in ir lant ### man brahte Rvedigeren da man Kriemhilten vant
###### 1193 | ### Vil minneclichen bitten der reke do began ### die edelen kvnniginne si solte in hoeren lan ### waz si enbieten wolte in Ecelen lant ### er niwan an ir niht anders niwan lovgenen vant
###### 1194 | ### daz si nimmer minnen wolte mer deheinen man ### do sprach der marchgraue daz were missetan ### zuo wiv woldet ir verderben einen also schoenen lip ### ir mvget noch mit eren werden guotes mannes wip
###### 1195 | ### Niht half daz si gebaten vnz daz Rudiger ### gesprach heinliche die kvnniginne her [49a] ### er wolte si ergezzen swaz ir ie gesach ### ein teil begvnd ir semften do ir grozer vngemach
###### 1196 | ### Er sprach zer kvniginne lat ivwer weinen sin ### ob ir zen Hvnen hetet nieman danne min ### getriwer miner mage vn– ovch der minen man ### er muos es sere engelten vn– het iv ieman iht getan
###### 1197 | ### Da von wart do geringet wol der vrowen mvot ### si sprach so swert mir eide swaz mir ieman getuot ### daz ir sit der nehste der buoze miniv leit ### do sprach der marchgraue des bin ich vrovwe vil bereit
###### 1198 | ### Mit allen sinen mannen swuor ir do Rvdiger ### mit triwen immer dienen vn– daz die reken her ### ir nimmer niht versageten vnz Ecelen lant ### des si eren haben solte des sichert ir do Rvdigers hant
###### 1199 | ### Do gedahte div getriwe sit ich vrivnde han ### also vil gewinnen so sol ich reden lan ### die lûte swaz si wellent ich iamerhaftez wip ### waz ob noch wirt errochen des minen mannes lip
###### 1200 | ### Si gedaht sit daz Ecele der reken hat so vil ### sol ich den gebieten so tuon ich swaz ich wil ### er ist ovch wol so riche daz ich ze gebene han ### mich hat der leidege Hagene mines guotes ane getan
###### 1201 | ### Si sprach ze Ruedigere het ich daz vernomen ### daz er niht were ein heiden so wer ich gerne komen ### swar er het willen vn– neme in zeinen man ### do sprach der markgraue die rede svlt ir vrovwe lan
###### 1202 | ### Er hat so vil der reken in kristenlicher ê ### daz iv bi dem kvnnige nimmer wirdet we ### waz ob ir daz verdienet daz er tovfet sinen lip ### des mvget ir gerne werden des kvniges Ecelen wip
###### 1203 | ### Do sprach aber ir bruoder nv lobez swester min ### ivwer vngemvote daz svlt ir lazen sin ### si batens also lange vnz daz doch ir trurich lip ### lobete vor den helden si wurde Ecelen wip
###### 1204 | ### Si sprach ich wil iv volgen ich vil arme kvnigin ### daz ich var ze den Hvnen so daz nv mach gesin ### swen ich han die frivnde die mich fueren in sin lant ### des bot do vor den helden div schoene Kriemhilt die hant
###### 1205 | ### Do sprach der marchgraue habet ir zwene man ### dar zuo han ich ir mere ez wirdet wol getan ### daz wir ivch wol nach eren bringen vber Rin ### irn svlt niht langer vrowe hie zen Burgonden sin
###### 1206 | ### Ich han funf hvndert manne vn– ovch der mage min ### die svln iv hie dienen vn– da heime sin ### vrowe swie ir gebietet ich tuon iv selbe alsam ### swan ir mich mant der <mere> daz ich michs nimmer gescham
###### 1207 | ### Nv heizet iv bereiten iwer pfertcleit ### die Ruedigers ræte iv nimmer werdent leit ### vn– saget ez iwer magden die ir da fueren welt ### ia chvmt vns vf der straze vil maniger vzerwelter helt [49b]
###### 1208 | ### Si heten noch gesmide daz man da vor treit ### bi <Sifrides> ziten daz si vil manige meit ### mit eren mohte fueren swenne si wolde von dan ### hei waz man schoener setele den schoenen vrovwen gewan
###### 1209 | ### Ob si ie getrovgen deheiniv richiv chleit ### der wart zuo zir verre vil maniges nv bereit ### wan in von den kvnige so vil gesaget wart ### si sluzzen vf die kisten die ê stvnden wol bespart
###### 1210 | ### Si waren vil vnmuozech wol viumphtehalben tac ### si svohten vz der valten des vil darinne lac ### Kriemhilde ir kameren ensliezen began ### si wolte machen riche alle die Ruedigers man
###### 1211 | ### Si hete noch des goldes von Niblunge lant ### si wande ez zen Hovunen solte teilen ir hant ### ez en kvnden hundert meule dannen niht getragen ### div mere horte Hagne do von Kriemhilde sagen
###### 1212 | ### Er sprach sit mir vro Kriemhit nimmer wirdet holt ### so mvoz ovch hie beliben daz Sifrides golt ### zewiv sold ich minen vienden lan so michel guot ### ich waiz vil wol waz Kriemhilt mit disme sazze getuot
###### 1213 | ### Ob si in brehte hinnen ich wil gelovben daz ### er wurde doch zerteilet vf den minen hals ### si habent ovch niht der rosse die in solten tragen ### in wil behalten Hagne daz sol man Kriemhilte sagen
###### 1214 | ### Do si gehorte div mere daz was ir grimme leit ### ez wart ovch den kvnnigen allen drien geseit ### si wolten ez gerne wenden do des niht geschach ### Ruodiger der edele harte vroliken sprach
###### 1215 | ### Richiv kvnniginne ce wiv claget ir daz golt ### iv ist der kvnich Ecele so grozlichen holt ### gesehent iv sin ovgen er git iv also vil ### daz vz verswendet nimmer des ich iv vrovwe weren wil
###### 1216 | ### Do sprach div vil edel kvniginne vil edeler Ruediger ### ez gewan nie kvniges tohter rihtume mer ### danne der mich Hagne hat ane getan ### do kom ir bruoder Gernot hin zer kameren gegan
###### 1217 | ### Mit gewalt des kvniges den sluzel stiez er an die tur ### golt daz Kriemhilde teilte man derfur ### ze drizech tusent marken oder dannoch baz ### er hiez ez nemen die geste liep was Gvnthere daz
###### 1218 | ### Do sprach von Bechelaren der Gothelinde man ### ob ez min vrowe Kriemhilt allez mohte han ### swaz sin ie gefueret von Niblvnge lant ### sin solte luzel rovren min oder der kvnniginne hant
###### 1219 | ### Nv heizet ez behalten wand ich niht enwil ### ia fuort ich von landen des minen also vil ### daz wirs vf der strazen haben guoten rat ### vn– vnser koste hinnen harte herliche stat
###### 1220 | ### Da vor in allen wilen gefullet zwelef schrin ### des aller besten goldes daz inder mohte sin [50a] ### hete die ir mage daz fuorten si von dan ### vn– gecierde vil der vrowen daz si cer uerten solten han
###### 1221 | ### Gewalt des grimmen Hagne duhte si ce starch ### si het ir <ophergoldes> noch wol tusent marc ### si teiltenz siner sele ir vil lieben man ### daz duhte Rudigeren min grozen triwen getan
###### 1222 | ### Do sprach div clagende kvnigin wa sint die vriunde min ### die durch mine liebe wellent ellende sin ### die svln mit mir riten in der Hunen <lant> ### die nemen schatz minen vn– kovvfen ros vn– ovch gewant
###### 1223 | ### Do sprach zer kvnniginne der marchgrave Ekewart ### sit daz ich aller erste iwer gesinde wart ### so han iv mit triwen gedienet sprach der degen ### vn– wil vns an min ende des selben immer bi iv pflegen
###### 1224 | ### Ich wil ovch mit mir fueren funf hvndert miner man ### der ich iv ce dienste mit rehten triwen gan ### wir sin vil vngescheiden ezen tuo danne der tot ### der rede neich im Criemhilt des gie ir werlichen not
###### 1225 | ### Do zoch man dar die moere si wolten varen dan ### da wart vil michel weinen von vrovden getan ### vote div vil rike vnd manic schoene meit ### die zeigten daz in were nach frov Criemhilt leit
###### 1226 | ### Hvndert richer mægde fuort si mit ir dan ### die wurden so gecleidet als in daz wol gezam ### do vielen in die trehne von liehten ovgen nider ### si gelebete vil der vienden ovch bi Ecelen sider
###### 1227 | ### Do chom der herre Giselher vn– ovch Gernot ### mit ir gesinde als in ir gesinde gebot ### do wolten si beleiten ir lieben swester dan ### do fuorten <si> ir reken wol tuset wetlicer man
###### 1228 | ### Do kom der snelle Gere vn– ovch Ortwin ### Kvmolt der kuchenmeister da mite muose sin ### si schuofen die nahtselde unz an Tuonawe stat ### do reit nihe furbaz Gvnther wan ein lucel fur die stat
###### 1229 | ### E si von Rine fuoren si heten fur gesant ### ir boten harte snelle nider Hunen lant ### die dem kvnge sagten daz im Ruediger ### ze wibe <hete> erworben die edelen kvniginne her

<<< Übersicht <<< vorige Seite nächste Seite >>>